This is an automated email from the ASF dual-hosted git repository.

knarendran pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/fluo-muchos.git


The following commit(s) were added to refs/heads/main by this push:
     new c894a7b  Call the method only for Azure clusters (#410)
c894a7b is described below

commit c894a7bbbd7f44ee0b53684c55db265817882785
Author: Karthick Narendran <[email protected]>
AuthorDate: Wed Aug 18 16:21:41 2021 +0000

    Call the method only for Azure clusters (#410)
    
    Co-authored-by: Karthick Narendran <[email protected]>
---
 lib/muchos/existing.py | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/lib/muchos/existing.py b/lib/muchos/existing.py
index 346917a..cb5eaa6 100644
--- a/lib/muchos/existing.py
+++ b/lib/muchos/existing.py
@@ -171,9 +171,10 @@ class ExistingCluster:
                     file=hosts_file,
                 )
 
-            # Call a method which can be used by different cluster types to
-            # write additional specialized configs into the Ansible hosts file
-            self.add_specialized_configs(hosts_file)
+            # Call the method for Azure cluster type to write additional
+            # specialized configs into the Ansible hosts file.
+            if config.cluster_type == "azure":
+                self.add_specialized_configs(hosts_file)
 
             print("\n[all:vars]", file=hosts_file)
             for (name, value) in sorted(host_vars.items()):

Reply via email to